

RegistryResource
=====================================

.. currentmodule:: pyvo.registry.regtap

.. autoclass:: RegistryResource
   :show-inheritance:

   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~RegistryResource.access_url
      ~RegistryResource.content_levels
      ~RegistryResource.content_types
      ~RegistryResource.creators
      ~RegistryResource.ivoid
      ~RegistryResource.reference_url
      ~RegistryResource.region_of_regard
      ~RegistryResource.res_description
      ~RegistryResource.res_title
      ~RegistryResource.res_type
      ~RegistryResource.service
      ~RegistryResource.short_name
      ~RegistryResource.source_format
      ~RegistryResource.standard_id
      ~RegistryResource.waveband

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~RegistryResource.describe
      ~RegistryResource.search

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: access_url
   .. autoattribute:: content_levels
   .. autoattribute:: content_types
   .. autoattribute:: creators
   .. autoattribute:: ivoid
   .. autoattribute:: reference_url
   .. autoattribute:: region_of_regard
   .. autoattribute:: res_description
   .. autoattribute:: res_title
   .. autoattribute:: res_type
   .. autoattribute:: service
   .. autoattribute:: short_name
   .. autoattribute:: source_format
   .. autoattribute:: standard_id
   .. autoattribute:: waveband

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: describe
   .. automethod:: search

   
   